==> RTNduals_1.0.3.tar.gz: RTNduals/R/AllGenerics.R <==
##generic functions
##------------------------------------------------------------------------------
setGeneric("mbrPreprocess",
           function(gexp, regulatoryElements1, regulatoryElements2, 
                    verbose=TRUE,...)
             standardGeneric("mbrPreprocess"), package="RTNduals")
setGeneric("mbrPermutation",
           function(object, verbose = TRUE, ...)
             standardGeneric("mbrPermutation"), package="RTNduals")
setGeneric("mbrBootstrap",
           function(object, verbose = TRUE, ...)
             standardGeneric("mbrBootstrap"), package="RTNduals")
setGeneric("mbrDpiFilter",
           function(object, verbose = TRUE, ...)
             standardGeneric("mbrDpiFilter"), package="RTNduals")
setGeneric("mbrAssociation",
           function(object, regulatoryElements1=NULL, 
                    regulatoryElements2=NULL, minRegulonSize=50, 
                    prob=0.95, estimator='spearman', 
                    pAdjustMethod="BH", verbose=TRUE)
             standardGeneric("mbrAssociation"), package="RTNduals")
setGeneric("mbrDuals",
           function(object, supplementaryTable = NULL,
                    evidenceColname=NULL, verbose = TRUE)
             standardGeneric("mbrDuals"), package="RTNduals")
setGeneric("tni2mbrPreprocess",
           function(TNI1, TNI2,
                    regulatoryElements1=NULL, regulatoryElements2=NULL,
                    verbose = TRUE)
             standardGeneric("tni2mbrPreprocess"), package="RTNduals")
setGeneric("mbrGet",
           function(object, what="status")
             standardGeneric("mbrGet"), package="RTNduals")

==> RTNduals_1.4.0.tar.gz: RTNduals/R/AllGenerics.R <==
##generic functions
##------------------------------------------------------------------------------
setGeneric("mbrPreprocess",
           function(gexp, regulatoryElements, verbose=TRUE,...)
             standardGeneric("mbrPreprocess"), package="RTNduals")
setGeneric("mbrPermutation",
           function(object, verbose = TRUE, ...)
             standardGeneric("mbrPermutation"), package="RTNduals")
setGeneric("mbrBootstrap",
           function(object, verbose = TRUE, ...)
             standardGeneric("mbrBootstrap"), package="RTNduals")
setGeneric("mbrDpiFilter",
           function(object, verbose = TRUE, ...)
             standardGeneric("mbrDpiFilter"), package="RTNduals")
setGeneric("mbrAssociation",
           function(object, regulatoryElements=NULL, minRegulonSize=15, 
                    pValueCutoff=0.001, pAdjustMethod="BH", 
                    estimator='spearman', nPermutations=1000, 
                    miFilter=TRUE, verbose=TRUE)
             standardGeneric("mbrAssociation"), package="RTNduals")
setGeneric("mbrPriorEvidenceTable",
           function(object, priorEvidenceTable, evidenceColname, verbose = TRUE)
             standardGeneric("mbrPriorEvidenceTable"), package="RTNduals")
setGeneric("tni2mbrPreprocess",
           function(tni, regulatoryElements=NULL, verbose = TRUE)
             standardGeneric("tni2mbrPreprocess"), package="RTNduals")
setGeneric("mbrGet",
           function(object, what="status")
             standardGeneric("mbrGet"), package="RTNduals")
